@@ -89,8 +89,14 @@
         var http_err = _.template('"<%- config.method %> <%- config.url %>": <%- status %> <%- statusText %>.');
 
         $httpProvider.interceptors.push(['$rootScope', '$q', 'X', function($rootScope, $q, X){ return {
-            // request: function(req){ console.log('Request', req); return req; },
-            // response: function(res){ return res; },
+            request: function(req){
+                X.emit('statusbar-state', { ajax_in_progress: true });
+                return req;
+            },
+            response: function(res){
+                X.emit('statusbar-state', { ajax_in_progress: false });
+                return res;
+            },
             // requestError: function(rej){ return $q.reject(rej); },
             responseError: function(rej){
                 X.emit('statusbar-state', { http_error: http_err(rej) });
@@ -165,18 +171,31 @@
 
     /** Statusbar
      */
-    overcApplication.controller('statusbarCtrl', ['$scope', 'X', function($scope, X){
+    overcApplication.controller('statusbarCtrl', ['$scope', '$timeout', 'X', function($scope, $timeout, X){
         /** Application state
          * @type {Object}
          */
         $scope.state = {
             supervisor_lag: 0,
-            http_error: '' // TODO: display list of errors, and remove after a timeout
+            http_error: '',
+            ajax_in_progress: false
         };
 
+        /** Event to update state fields
+         * X.emit('statusbar-state', { ajax_in_progress: true });
+         */
         $scope.$on('statusbar-state', function(event, state){
             _.extend($scope.state, state);
         });
+
+        /** Unset HTTP error messages after a timeout
+         */
+        $scope.$watch('state.http_error', function(val, oldVal){
+            if (val)
+                $timeout(function(){
+                    $scope.state.http_error = '';
+                }, 3000);
+        });
     }]);
 
     /** Services controller
